@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import Dict, List, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, root_validator
 from pydantic.networks import HttpUrl
 from typing_extensions import Literal
 
@@ -16,7 +16,7 @@ class SnsNotificationModel(BaseModel):
     TopicArn: str
     UnsubscribeUrl: HttpUrl
     Type: Literal["Notification"]
-    MessageAttributes: Dict[str, SnsMsgAttributeModel]
+    MessageAttributes: Optional[Dict[str, SnsMsgAttributeModel]]
     Message: str
     MessageId: str
     SigningCertUrl: HttpUrl
@@ -24,6 +24,14 @@ class SnsNotificationModel(BaseModel):
     Timestamp: datetime
     SignatureVersion: str
 
+    @root_validator(pre=True)
+    def check_sqs_protocol(cls, values):
+        sqs_rewritten_keys = ("UnsubscribeURL", "SigningCertURL")
+        if any(key in sqs_rewritten_keys for key in values):
+            values["UnsubscribeUrl"] = values.pop("UnsubscribeURL")
+            values["SigningCertUrl"] = values.pop("SigningCertURL")
+        return values
+
 
 class SnsRecordModel(BaseModel):
     EventSource: Literal["aws:sns"]
